@@ -3,6 +3,8 @@ import sys
 import logging
 from datetime import date
 
+from mysqld_integration_test.exceptions import InvalidLogLevel
+
 class bcolors:
     HEADER = '\033[95m'
     OKBLUE = '\033[94m'
@@ -13,13 +15,11 @@ class bcolors:
     BOLD = '\033[1m'
     UNDERLINE = '\033[4m'
 
-
 class _Log():
     def __init__(self):
         logging.debug("magic")
         self.logger = logging.getLogger('mysqld-integration-test')
-        self.logger.setLevel(logging.INFO)
-
+        self.logger.setLevel(logging.ERROR)
 
     def debug(self, msg):
         if self.logger:
@@ -44,4 +44,16 @@ class _Log():
         if self.logger:
             self.logger.info(self._colored(msg, bcolors.OKGREEN))
 
+    def setlevel(self, log_level):
+        if log_level == "INFO":
+            self.logger.setLevel(logging.INFO)
+        elif log_level == "DEBUG":
+            self.logger.setLevel(logging.DEBUG)
+        elif log_level == 'ERROR':
+            self.logger.setLevel(logging.ERROR)
+        elif log_level == 'WARN':
+            self.logger.setLevel(logging.WARN)
+        else:
+            raise InvalidLogLevel
+
 logger = _Log()
